phomemo library

Classes

ImagePainter
Phomemo
packetSize the max size of the information you wish to send to the printer 512 is the largest value. Other values are 8,16,32,128,256
PhomemoHelper
This is a helper to create lables from text or images
PhomemoOptions
Print perameters for the printer sizeMode the size of the image to print justification for m02 type for alignment labelType for the mType printers for the type of lable speed how fast to print 1 - 5 (slow - fast) darkness how dark to make the ink 1 - 10 (light - dark)

Enums

PhomemoJustification
Only used for M02
PhomemoLabelType
This is for the M type printers to change tpye of label
PhomemoPacketSize
PhomemoPrinter
Phomemo printes that have been tested and are supported
PhomemoSizeMode
This is for the M type printers to change size of the image printed