PhomemoPrinter enum

Phomemo printes that have been tested and are supported

Inheritance
Available extensions

Values

p12pro → const PhomemoPrinter
d30 → const PhomemoPrinter
d35 → const PhomemoPrinter
m110 → const PhomemoPrinter
m120 → const PhomemoPrinter
m220 → const PhomemoPrinter
m02 → const PhomemoPrinter

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isDType(PhomemoPrinter printer) bool
isM1Type(PhomemoPrinter printer) bool
isMType(PhomemoPrinter printer) bool

Constants

values → const List<PhomemoPrinter>
A constant List of the values in this enum, in order of their declaration.